==> yybbs-0.54.zip: yybbs/viewbbs.php <==
<?php
/**
@brief 򤵤줿 BBS ɽ
@version $Id: viewbbs.php,v 1.5 2004/07/25 16:23:15 minahito Exp $
*/

include "../../mainfile.php";
include XOOPS_ROOT_PATH."/header.php";

require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";

require_once "./class/global.php";
require_once "./class/user.php";	// ɤ߹Ǥ

require_once "exForm/Form.php";

require_once "./include/YYBBSListController.php";
require_once "./include/MessageFilter.php";

    $filter=new MessageThreadFilter();
    
    $handler=&YYBBS::getHandler('bbs');
    $bbs=&$handler->get($filter->bbs_id_);
    
    // ƥץ졼ȤΤΥ桼
    $user = new YYBBSUser($xoopsUser);
    $cookieUser = new YYBBSCookieUser();
    $cookieUser->getCookie();
    $user->cookieUser_=&$cookieUser;
    
    // ƥץ졼ȤΤΥå
    $mHandler=&YYBBS::getHandler('message');
    $post = $mHandler->create();
    $post->setDefault($user->cookieUser_);
    if(!strlen($post->getVar('col'))) {
    	$tmp=$bbs->getColorArray();
    	$post->setVar('col',$tmp[0]);
    }
    
    // եΤ˥Ф
    $handler=&YYBBS::getHandler('icon');
    $icons=&$handler->getObjects(null,null,'priority');
    
    if(!is_object($bbs))
    	redirect_header("index.php",1,"ʥǤ");
    
    $listController=new YYBBSListController();
    $listController->filter_=&$filter;
    $listController->fetch($mHandler->getCount($filter->getCriteria()),$bbs->getVar('page_limit'));
    
    $messages =& $mHandler->getObjects($listController->getCriteria());

    // View
    $xoopsOption['template_main'] = 'yybbs_forum.html';
    $xoopsTpl->assign('bbs',$bbs->getStructure());
    $xoopsTpl->assign('bbsUser',$user->getStructure());
    $xoopsTpl->assign('post',$post->getStructure('e'));
    foreach($icons as $icon){
    	$xoopsTpl->append('icons',$icon->getStructure());
    }
    foreach($messages as $message){
    	$message->load();
    	$xoopsTpl->append('messages',$message->getStructure());
    }
    $listController->freeze();
    $xoopsTpl->assign('navi',$listController->getStructure());

include XOOPS_ROOT_PATH."/footer.php";

?>

==> yybbs-0.55.zip: yybbs/viewbbs.php <==
<?php
/**
@brief 򤵤줿 BBS ɽ
@version $Id: viewbbs.php,v 1.8 2004/08/04 16:35:58 minahito Exp $
*/

include "../../mainfile.php";
include XOOPS_ROOT_PATH."/header.php";

require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";

require_once "./class/global.php";
require_once "./class/user.php";	// ɤ߹Ǥ

require_once "exForm/Form.php";

require_once "./include/YYBBSListController.php";
require_once "./include/MessageFilter.php";

require_once "xoops/perm.php";

	// ե륿ʳĥ
	if(isset($_REQUEST['serial']))
		$filter = new MessageOneThreadSerialFilter();
	else
		$filter = isset($_REQUEST['id']) ? new MessageOneThreadIDFilter() : new MessageThreadFilter();
    
    $handler=&YYBBS::getHandler('bbs');
    $bbs=&$handler->get($filter->bbs_id_);
    if(!is_object($bbs))
    	redirect_header("index.php",1,"ʥǤ");

	// ¤θ
	if($xoopsModuleConfig['permission']){
		if(!exPerm::Guard_global('view_bbs',$bbs->getVar('bbs_id'))) {
			redirect_header("index.php",1,_MD_YYBBS_ERRMES_PERM);
		} 
	}

   
    // ƥץ졼ȤΤΥ桼
    $user = new YYBBSUser($xoopsUser);
    $cookieUser = new YYBBSCookieUser();
    $cookieUser->getCookie();
    $user->cookieUser_=&$cookieUser;
    
    // ƥץ졼ȤΤΥå
    $mHandler=&YYBBS::getHandler('message');
    $post = $mHandler->create();
    $post->setDefault($user->cookieUser_);
    if(!strlen($post->getVar('col'))) {
    	$tmp=$bbs->getColorArray();
    	$post->setVar('col',$tmp[0]);
    }
    
    // եΤ˥Ф
    $handler=&YYBBS::getHandler('icon');
    $icons=&$handler->getObjects(null,null,'priority');
   
    $listController=new YYBBSListController();
    $listController->filter_=&$filter;
    $listController->fetch($mHandler->getCount($filter->getCriteria()),$bbs->getVar('page_limit'));
    if($listController->filter_->isError())
    	redirect_header("index.php",1,"ʥǤ");
    
    $messages =& $mHandler->getObjects($listController->getCriteria());

    // View
    $xoopsOption['template_main'] = 'yybbs_forum.html';
    $xoopsTpl->assign('bbs',$bbs->getStructure());
    $xoopsTpl->assign('bbsUser',$user->getStructure4User('s',$bbs->getVar('bbs_id')));
    $xoopsTpl->assign('post',$post->getStructure('e'));
    foreach($icons as $icon){
    	$xoopsTpl->append('icons',$icon->getStructure());
    }
    foreach($messages as $message){
    	$message->load();
    	$xoopsTpl->append('messages',$message->getStructure());
    }
    $listController->freeze();
    $xoopsTpl->assign('navi',$listController->getStructure());

include XOOPS_ROOT_PATH."/footer.php";

?>
